#include "./Button.h"

Button::Button(uint8_t buttonPin, char key, unsigned long debounceMs) {
    pin = buttonPin;
    keyToSend = key;
    currentState = HIGH;        
    lastReading = HIGH;  
    lastDebounceTime = 0;
    debounceDelay = debounceMs;
}

void Button::begin() {
    pinMode(pin, INPUT_PULLUP);
}

bool Button::update() {
    bool stateChanged = false;

    int reading = digitalRead(pin);
    
    if (reading != lastReading) {
        lastDebounceTime = millis();
    }
    
    if ((millis() - lastDebounceTime) > debounceDelay) {
        if (reading != currentState) {
            currentState = reading;
            stateChanged = true;
            
            if (currentState == LOW) {
                Keyboard.press(keyToSend);
            } else {
                Keyboard.release(keyToSend);
            }
        }
    }

    lastReading = reading;
    return stateChanged;
}

bool Button::getState() const {
    return currentState;
}

void Button::setKey(char newKey) {
    keyToSend = newKey;
} 